package cn.com.infosec.mobile.android.xlog.printer.file;

import android.support.annotation.Keep;
import cn.com.infosec.mobile.android.xlog.flattener.Flattener;
import cn.com.infosec.mobile.android.xlog.flattener.Flattener2;
import cn.com.infosec.mobile.android.xlog.internal.DefaultsFactory;
import cn.com.infosec.mobile.android.xlog.internal.Platform;
import cn.com.infosec.mobile.android.xlog.internal.printer.file.backup.BackupStrategyWrapper;
import cn.com.infosec.mobile.android.xlog.internal.printer.file.backup.BackupUtil;
import cn.com.infosec.mobile.android.xlog.printer.Printer;
import cn.com.infosec.mobile.android.xlog.printer.file.backup.BackupStrategy;
import cn.com.infosec.mobile.android.xlog.printer.file.backup.BackupStrategy2;
import cn.com.infosec.mobile.android.xlog.printer.file.clean.CleanStrategy;
import cn.com.infosec.mobile.android.xlog.printer.file.naming.FileNameGenerator;
import cn.com.infosec.mobile.android.xlog.printer.file.writer.Writer;
import java.io.File;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;

@Keep
public class FilePrinter implements Printer {
   private static final boolean USE_WORKER = true;
   private final String folderPath;
   private final FileNameGenerator fileNameGenerator;
   private final BackupStrategy2 backupStrategy;
   private final CleanStrategy cleanStrategy;
   private Flattener2 flattener;
   private Writer writer;
   private volatile Worker worker;

   FilePrinter(Builder builder) {
      this.folderPath = builder.folderPath;
      this.fileNameGenerator = builder.fileNameGenerator;
      this.backupStrategy = builder.backupStrategy;
      this.cleanStrategy = builder.cleanStrategy;
      this.flattener = builder.flattener;
      this.writer = builder.writer;
      this.worker = new Worker();
      this.checkLogFolder();
   }

   private void checkLogFolder() {
      File var1;
      File var10000 = var1 = new File;
      var10000.<init>(this.folderPath);
      if (!var10000.exists()) {
         var1.mkdirs();
      }

   }

   private void doPrintln(long timeMillis, int logLevel, String tag, String msg) {
      String var8;
      label47: {
         String var6;
         String var10000 = var6 = this.writer.getOpenedFileName();
         boolean var7 = this.writer.isOpened() ^ true;
         if (var10000 == null || var7 || this.fileNameGenerator.isFileNameChangeable()) {
            if ((var8 = this.fileNameGenerator.generateFileName(logLevel, System.currentTimeMillis())) == null || var8.trim().length() == 0) {
               Platform.get().error("File name should not be empty, ignore log: " + msg);
               return;
            }

            if (!var8.equals(var6) || var7) {
               this.writer.close();
               this.cleanLogFilesIfNecessary();
               if (!this.writer.open(new File(this.folderPath, var8))) {
                  return;
               }
               break label47;
            }
         }

         var8 = var6;
      }

      File var11 = this.writer.getOpenedFile();
      if (this.backupStrategy.shouldBackup(var11)) {
         this.writer.close();
         BackupUtil.backup(var11, this.backupStrategy);
         if (!this.writer.open(new File(this.folderPath, var8))) {
            return;
         }
      }

      FilePrinter var10 = this;
      String var9 = this.flattener.flatten(timeMillis, logLevel, tag, msg).toString();
      var10.writer.appendLog(var9);
   }

   private void cleanLogFilesIfNecessary() {
      File[] var1;
      if ((var1 = (new File(this.folderPath)).listFiles()) != null) {
         int var2 = var1.length;

         for(int var3 = 0; var3 < var2; ++var3) {
            File var4 = var1[var3];
            if (this.cleanStrategy.shouldClean(var4)) {
               var4.delete();
            }
         }

      }
   }

   public void println(int logLevel, String tag, String msg) {
      long var4 = System.currentTimeMillis();
      if (!this.worker.isStarted()) {
         this.worker.start();
      }

      this.worker.enqueue(new LogItem(var4, logLevel, tag, msg));
   }

   private class Worker implements Runnable {
      private BlockingQueue<LogItem> logs;
      private volatile boolean started;

      private Worker() {
         Worker var10000 = this;
         super();
         LinkedBlockingQueue var2;
         var2 = new LinkedBlockingQueue.<init>();
         var10000.logs = var2;
      }

      // $FF: synthetic method
      Worker(Object x1) {
         this();
      }

      void enqueue(LogItem log) {
         try {
            this.logs.put(log);
         } catch (InterruptedException var2) {
            var2.printStackTrace();
         }

      }

      boolean isStarted() {
         Worker var10000 = this;
         synchronized(this) {
            return var10000.started;
         }
      }

      void start() {
         Worker var10000 = this;
         synchronized(this){}

         boolean var10001;
         Throwable var14;
         boolean var15;
         try {
            var15 = var10000.started;
         } catch (Throwable var13) {
            var14 = var13;
            var10001 = false;
            throw var14;
         }

         if (var15) {
            try {
               ;
            } catch (Throwable var11) {
               var14 = var11;
               var10001 = false;
               throw var14;
            }
         } else {
            try {
               (new Thread(this)).start();
               this.started = true;
            } catch (Throwable var12) {
               var14 = var12;
               var10001 = false;
               throw var14;
            }
         }
      }

      public void run() {
         InterruptedException var10000;
         while(true) {
            LogItem var14;
            boolean var10001;
            try {
               var14 = (LogItem)this.logs.take();
            } catch (InterruptedException var12) {
               var10000 = var12;
               var10001 = false;
               break;
            }

            LogItem var1 = var14;
            if (var14 == null) {
               return;
            }

            FilePrinter var15;
            LogItem var16;
            LogItem var10002;
            LogItem var10003;
            long var10004;
            try {
               var15 = FilePrinter.this;
               var16 = var1;
               var10002 = var1;
               var10003 = var1;
               var10004 = var1.timeMillis;
            } catch (InterruptedException var11) {
               var10000 = var11;
               var10001 = false;
               break;
            }

            long var13 = var10004;

            int var20;
            try {
               var20 = var10003.level;
            } catch (InterruptedException var10) {
               var10000 = var10;
               var10001 = false;
               break;
            }

            int var3 = var20;

            String var17;
            try {
               var17 = var10002.tag;
            } catch (InterruptedException var9) {
               var10000 = var9;
               var10001 = false;
               break;
            }

            String var4 = var17;

            String var19;
            try {
               var19 = var16.msg;
            } catch (InterruptedException var8) {
               var10000 = var8;
               var10001 = false;
               break;
            }

            String var5 = var19;

            try {
               var15.doPrintln(var13, var3, var4, var5);
            } catch (InterruptedException var7) {
               var10000 = var7;
               var10001 = false;
               break;
            }
         }

         var10000.printStackTrace();
         Worker var18 = this;
         Worker var21 = this;
         synchronized(this) {
            var21.started = false;
         }

      }
   }

   private static class LogItem {
      long timeMillis;
      int level;
      String tag;
      String msg;

      LogItem(long timeMillis, int level, String tag, String msg) {
         this.timeMillis = timeMillis;
         this.level = level;
         this.tag = tag;
         this.msg = msg;
      }
   }

   public static class Builder {
      String folderPath;
      FileNameGenerator fileNameGenerator;
      BackupStrategy2 backupStrategy;
      CleanStrategy cleanStrategy;
      Flattener2 flattener;
      Writer writer;

      public Builder(String folderPath) {
         this.folderPath = folderPath;
      }

      private void fillEmptyFields() {
         if (this.fileNameGenerator == null) {
            this.fileNameGenerator = DefaultsFactory.createFileNameGenerator();
         }

         if (this.backupStrategy == null) {
            this.backupStrategy = DefaultsFactory.createBackupStrategy();
         }

         if (this.cleanStrategy == null) {
            this.cleanStrategy = DefaultsFactory.createCleanStrategy();
         }

         if (this.flattener == null) {
            this.flattener = DefaultsFactory.createFlattener2();
         }

         if (this.writer == null) {
            this.writer = DefaultsFactory.createWriter();
         }

      }

      public Builder fileNameGenerator(FileNameGenerator fileNameGenerator) {
         this.fileNameGenerator = fileNameGenerator;
         return this;
      }

      public Builder backupStrategy(BackupStrategy backupStrategy) {
         Object var2;
         if (!(backupStrategy instanceof BackupStrategy2)) {
            var2 = new BackupStrategyWrapper.<init>(backupStrategy);
         } else {
            var2 = backupStrategy;
         }

         BackupUtil.verifyBackupStrategy(this.backupStrategy = (BackupStrategy2)var2);
         return this;
      }

      public Builder cleanStrategy(CleanStrategy cleanStrategy) {
         this.cleanStrategy = cleanStrategy;
         return this;
      }

      /** @deprecated */
      @Deprecated
      public Builder logFlattener(final Flattener flattener) {
         return this.flattener(new Flattener2() {
            public CharSequence flatten(long timeMillis, int logLevel, String tag, String message) {
               return flattener.flatten(logLevel, tag, message);
            }
         });
      }

      public Builder flattener(Flattener2 flattener) {
         this.flattener = flattener;
         return this;
      }

      public Builder writer(Writer writer) {
         this.writer = writer;
         return this;
      }

      public FilePrinter build() {
         this.fillEmptyFields();
         return new FilePrinter(this);
      }
   }
}
